jQuery(document).ready(function($){
    $.widget.bridge('uiTooltip', $.ui.tooltip);

    var TiredPriceTable = function() {

        this.settings                 = tieredPricingTable.settings;
        this.productType              = tieredPricingTable.product_type;
        this.$productQuantityField    = $('form.cart').find('[name=quantity]');
        this.tieredPriceTableSelector = '[data-price-rules-table]';
        this.defaultPriceHtml         = $('[data-price-rules-amount=1]').find('[data-price-rules-formated-price]').html();
        this.priceContainerSelector   = '[data-tiered-price-wrapper]';

        this.init = function(){

            if(this.settings !== undefined){
                if(this.productType === 'variable') {
                    $( ".single_variation_wrap" ).on( "show_variation", this.loadVariationTable.bind(this));

                    $(document).on('reset_data', function() {
                        $('[data-variation-price-rules-table]').html('');
                    });
                }

                if(this.settings.display_type === 'tooltip') {
                    this.initTooltip();
                }

                this.$productQuantityField.on('input', this.setPriceByQuantity.bind(this));

                this.$productQuantityField.trigger('input');
            }
        };

        this.initTooltip = function () {
            var self = this;

            if(this.settings.tooltip_border === 'yes') {
                $(self.tieredPriceTableSelector).css('border', '2px solid ' + this.settings.selected_quantity_color);
            }


            $(document).uiTooltip({
                items: '.price-table-tooltip-icon',
                tooltipClass: "price-table-tooltip",
                content: function () {
                    return $(self.tieredPriceTableSelector);
                },
                hide: {
                    effect: "fade",
                },
                position: {
                    my: "center bottom-40",
                    at: "center bottom",
                    using: function( position ) {
                        $( this ).css( position );
                    }
                },
                close: function (e, tooltip) {
                    tooltip.tooltip.innerHTML = '';
                }
            });
        };

        this.setPriceByQuantity = function(){
            $('.price-rule-active').removeClass('price-rule-active');

            if($(this.tieredPriceTableSelector).length > 0){

                var priceRules = JSON.parse($(this.tieredPriceTableSelector).attr('data-price-rules'));

                var quantity   = parseInt(this.$productQuantityField.val());
                var _keys      = [];

                for (var k in priceRules) {
                    if (priceRules.hasOwnProperty(k)) {
                        _keys.push(parseInt(k));
                    }
                }

                _keys = _keys.sort(function(a, b){return a > b}).reverse();

                for (var i = 0; i < _keys.length; i++) {
                    var amount = parseInt(_keys[i]);
                    var findPrice = false;
                    var priceHtml;

                    if(quantity >= amount){
                        priceHtml = $('[data-price-rules-amount='+amount+']').find('[data-price-rules-formated-price]').html();

                        this.changePriceHtml(priceHtml);
                        findPrice = true;

                        break;
                    }
                }

                if(!findPrice){
                    this.changePriceHtml(this.defaultPriceHtml);
                    $('[data-price-rules-amount=1]').addClass('price-rule-active');
                    return;
                }

                $('[data-price-rules-amount="'+amount+'"]').addClass('price-rule-active');
            }

        };

        this.changePriceHtml = function(priceHtml){
            var priceContainer = $('form.cart').closest('.summary').find('[data-tiered-price-wrapper]');

            if(priceContainer.children('ins').length > 0 ){
                priceContainer.find('ins').html(priceHtml);
            }else{
                priceContainer.find('span:first').html(priceHtml);
            }
        };

        this.loadVariationTable = function( event, variation ) {

            $.post(document.location.pathname + '?wc-ajax=get_price_table', { variation_id: variation['variation_id'] }, (function(response){
                $('.price-rules-table').remove();
                $('[data-variation-price-rules-table]').html(response);
                this.$productQuantityField.trigger('input');

                $(this.tieredPriceTableSelector).css('border', '2px solid ' + this.settings.selected_quantity_color);

            }).bind(this));
        }
    };

    var tieredPriceTable = new TiredPriceTable();

    tieredPriceTable.init();
});

